@@ -1,9 +1,7 @@
 import numpy as np
-import miplib.processing.deconvolution.wiener as wiener
-
+import miplib.processing.deconvolution.wiener_cuda as wiener
 from miplib.data.containers.image_data import ImageData
 
-
 def wiener_fusion(data, options, gate=0, scale=100, views=None):
     assert isinstance(data, ImageData)
 
